@@ -19,6 +19,9 @@
 #' @param use_category A Boolean value to specify whether the categorical
 #'     summary instead of the total summary.
 #'
+#' @param multiplot_lib A string to decide which library is used to combine
+#'    multiple plots. Either "patchwork" or "grid".
+#'
 #' @param ... Not used by this function.
 #'
 #' @return A data frame with validation results.
@@ -32,19 +35,23 @@
 #' eres1 <- run_evalcurve(testset, toolset)
 #' autoplot(eres1)
 #'
+#' @name autoplot
+#' @export
+NULL
+
 #' @rdname autoplot
 #' @export
 autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
                                ncol = NULL, nrow = NULL, use_category = FALSE,
-                               ...) {
-  if (!requireNamespace("ggplot2", quietly = TRUE)) {
-    stop("ggplot2 needed for this function to work. Please install it.",
-         call. = FALSE)
-  }
+                               multiplot_lib = "patchwork", ...) {
+  .load_ggplot2()
 
   # Validate arguments
-  new_args <- .validate_autoplot_evalcurve_args(object, base_plot, ret_grob,
-                                                ncol, nrow, use_category, ...)
+  new_args <- .validate_autoplot_evalcurve_args(
+    object, base_plot, ret_grob,
+    ncol, nrow, use_category,
+    multiplot_lib, ...
+  )
 
   # Create plots
   plots <- .create_plots(new_args$object, use_category)
@@ -54,14 +61,52 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
   }
 
   # Combine multiple plots
-  ncolrow = .get_row_col(new_args$ncol, new_args$nrow, length(plots))
+  ncolrow <- .get_row_col(new_args$ncol, new_args$nrow, length(plots))
 
-  ggrob <- .combine_plots(plots, ncolrow$ncol, ncolrow$nrow)
+  .combine_plots(plots, new_args, ncolrow$ncol, ncolrow$nrow)
+}
 
-  if (new_args$ret_grob) {
-    return(ggrob)
+#
+# Load ggplot2
+#
+.load_ggplot2 <- function() {
+  if (!requireNamespace("ggplot2", quietly = TRUE)) {
+    msg <- "ggplot2 is required to run this funcion"
+    stop(msg, call. = FALSE)
+  }
+}
+
+#
+# Load grid
+#
+.load_grid <- function() {
+  if (!requireNamespace("grid", quietly = TRUE)) {
+    msg <- "grid is required to run this funcion"
+    stop(msg, call. = FALSE)
+  }
+}
+
+#
+# Load gridExtra
+#
+.load_gridextra <- function() {
+  if (!requireNamespace("gridExtra", quietly = TRUE)) {
+    msg <- "gridExtra is required to run this funcion"
+    stop(msg, call. = FALSE)
+  }
+}
+
+#
+# Load patchwork
+#
+.load_patchwork <- function() {
+  if (requireNamespace("patchwork", quietly = TRUE)) {
+    return(TRUE)
   } else {
-    .plot_grob(ggrob)
+    msg1 <- "patchwork is not available. "
+    msg2 <- "grid and gridExtra will be used instead."
+    warning(paste0(msg1, msg2), call. = FALSE)
+    return(FALSE)
   }
 }
 
@@ -103,14 +148,16 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
     toolset <- unamevec[1]
     toolname <- unamevec[2]
 
-    pcrows <- preds$toolset == toolset & preds$toolname == toolname
+    pcrows <- (preds$toolset == toolset) & (preds$toolname == toolname)
     pcurves <- preds[pcrows, ]
 
-    tsrows <- tscores$toolset == toolset & tscores$toolname == toolname
+    tsrows <- (tscores$toolset == toolset) & (tscores$toolname == toolname)
     tscore <- tscores[tsrows, ]
 
-    .plot_curves(evalcurve$basepoints, pcurves, tscore,
-                 evalcurve$titles[i], use_category)
+    .plot_curves(
+      evalcurve$basepoints, pcurves, tscore,
+      toolname, use_category
+    )
   }
 
   lapply(seq_along(uniqnames), plotfunc)
@@ -123,13 +170,19 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
 .plot_base <- function(basepoints, title = "Base points",
                        yintercept = 0.5) {
   p <- ggplot2::ggplot()
-  p <- p + ggplot2::geom_hline(yintercept = yintercept, colour = "grey",
-                               linetype = 3)
-  p <- p + ggplot2::geom_point(data = basepoints,
-                               ggplot2::aes_string(x = "x", y = "y",
-                                                   colour = "testset",
-                                                   shape = "testset"),
-                               size = 2)
+  p <- p + ggplot2::geom_hline(
+    yintercept = yintercept, colour = "grey",
+    linetype = 3
+  )
+  p <- p + ggplot2::geom_point(
+    data = basepoints,
+    ggplot2::aes_string(
+      x = "x", y = "y",
+      colour = "testset",
+      shape = "testset"
+    ),
+    size = 2
+  )
   p <- p + ggplot2::scale_shape(solid = FALSE)
   p <- p + ggplot2::theme_bw()
   p <- p + ggplot2::ggtitle(title)
@@ -146,52 +199,97 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
 #
 .plot_curves <- function(basepoints, pcurves, tscore, toolname,
                          use_category, yintercept = 0.5) {
-
   p <- .plot_base(basepoints, toolname, yintercept)
-  p <- p + ggplot2::geom_line(data = pcurves,
-                              ggplot2::aes_string(x = "x", y = "y",
-                                                  colour = "testset"))
+  p <- p + ggplot2::geom_line(
+    data = pcurves,
+    ggplot2::aes_string(
+      x = "x", y = "y",
+      colour = "testset"
+    )
+  )
 
   if (use_category) {
-    p <- p + ggplot2::geom_label(data = tscore,
-                                 size = 3,
-                                 colour = "white",
-                                 fontface = "bold",
-                                 alpha = 0.75,
-                                 ggplot2::aes_string(x = "lbl_pos_x2",
-                                                     y = "lbl_pos_y2",
-                                                     label = "label2",
-                                                     fill = "testset"))
+    p <- p + ggplot2::geom_label(
+      data = tscore,
+      size = 3,
+      colour = "white",
+      fontface = "bold",
+      alpha = 0.75,
+      ggplot2::aes_string(
+        x = "lbl_pos_x2",
+        y = "lbl_pos_y2",
+        label = "label2",
+        fill = "testset"
+      )
+    )
   } else {
-    p <- p + ggplot2::geom_label(data = tscore,
-                                 ggplot2::aes_string(x = "lbl_pos_x",
-                                                     y = "lbl_pos_y",
-                                                     label = "label",
-                                                     color = "testset"))
+    p <- p + ggplot2::geom_label(
+      data = tscore,
+      ggplot2::aes_string(
+        x = "lbl_pos_x",
+        y = "lbl_pos_y",
+        label = "label",
+        color = "testset"
+      )
+    )
   }
-
 }
 
 #
-# Plot curves for a specified tool
+# Plot curves for a specified tool with grid and gridExtra
 #
-.combine_plots <- function(plots, ncol, nrow) {
+.combine_plots_grid <- function(plots, ncol, nrow) {
   if (!requireNamespace("gridExtra", quietly = TRUE)) {
     stop("gridExtra needed for this function to work. Please install it.",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
 
-  gfunc <- function(...) {gridExtra::arrangeGrob(..., ncol = ncol, nrow = nrow)}
+  gfunc <- function(...) {
+    gridExtra::arrangeGrob(..., ncol = ncol, nrow = nrow)
+  }
   suppressWarnings(do.call(gfunc, plots))
 }
 
+#
+# Combine ROC and Precision-Recall plots by patchwork
+#
+.combine_plots_patchwork <- function(plots, ncol, nrow) {
+  patchwork::wrap_plots(plots, ncol = ncol, nrow = nrow)
+}
+
+#
+# Combine ROC and Precision-Recall plots
+#
+.combine_plots <- function(plots, args, ncol, nrow) {
+  multiplot_lib <- args$multiplot_lib
+  if (multiplot_lib == "patchwork") {
+    if (.load_patchwork()) {
+      return(.combine_plots_patchwork(plots, ncol, nrow))
+    } else {
+      multiplot_lib <- "grid"
+    }
+  }
+  if (multiplot_lib == "grid") {
+    .load_grid()
+    .load_gridextra()
+    ggrob <- .combine_plots_grid(plots, ncol, nrow)
+    if (args$ret_grob) {
+      return(ggrob)
+    } else {
+      .plot_grob(ggrob)
+    }
+  }
+}
+
 #
 # Plot grob object
 #
 .plot_grob <- function(grob) {
   if (!requireNamespace("grid", quietly = TRUE)) {
     stop("grid needed for this function to work. Please install it.",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
   graphics::plot.new()
   grid::grid.draw(grob)
@@ -201,8 +299,8 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
 # Validate arguments and return updated arguments
 #
 .validate_autoplot_evalcurve_args <- function(object, base_plot, ret_grob, ncol,
-                                              nrow, use_category, ...) {
-
+                                              nrow, use_category, multiplot_lib,
+                                              ...) {
   if (!methods::is(object, "evalcurve")) {
     stop("Ivalid object type", call. = FALSE)
   }
@@ -216,13 +314,21 @@ autoplot.evalcurve <- function(object, base_plot = TRUE, ret_grob = FALSE,
 
     assertthat::assert_that(assertthat::is.number(nrow))
     assertthat::assert_that(nrow > 0)
-  } else if ((!is.null(ncol) && is.null(nrow))
-             || (is.null(ncol) && !is.null(nrow))) {
+  } else if ((!is.null(ncol) && is.null(nrow)) ||
+    (is.null(ncol) && !is.null(nrow))) {
     stop("Both ncol and nrow must be set", call. = FALSE)
   }
 
   assertthat::assert_that(assertthat::is.flag(use_category))
 
-  list(object = object, base_plot = base_plot, ret_grob = ret_grob, ncol = ncol,
-       nrow = nrow, use_category = use_category)
+  assertthat::assert_that(
+    is.atomic(multiplot_lib),
+    is.character(multiplot_lib),
+    multiplot_lib %in% c("patchwork", "grid")
+  )
+
+  list(
+    object = object, base_plot = base_plot, ret_grob = ret_grob, ncol = ncol,
+    nrow = nrow, use_category = use_category, multiplot_lib = multiplot_lib
+  )
 }
